@@ -177,7 +177,6 @@ class Figure:
                 x1, y1 = self.xform(bbox.xmax, bbox.ymax)
                 clip = ET.fromstring(f'''<defs>
     <clipPath id="clip{clipid}"><rect x="{x0-1}" y="{y0-1}" width="{x1-x0+2}" height="{y1-y0+2}" /></clipPath></defs>''')
-                print(ET.tostring(clip))
                 self.svgelements.append((0, clip))
             et.set('clip-path', f'url(#clip{clipid})')
 
@@ -214,8 +213,9 @@ class Figure:
             return
 
         y += fontsize/72*2/6  # A bit of baseline shift to match MPL
-        x, y = self.xform(x, y)
-
+        x0, y0 = self.xform(x, y)
+        x, y = x0, y0
+        
         if ziamath and textmode == 'path':
             texttag = ET.Element('g')
             if fontfamily.lower() in ['sans-serif', 'Arial']:
@@ -248,7 +248,7 @@ class Figure:
                 yi += dy
 
             if rotation:
-                texttag.set('transform', f'rotate({-rotation} {x} {y})')
+                texttag.set('transform', f'rotate({-rotation} {x0} {y0})')
 
         else:
             texttag = svgtext.text_tosvg(s, x, y, font=fontfamily, size=fontsize,
@@ -290,7 +290,7 @@ class Figure:
         self.svgelements.append((zorder, et))
 
     def arrow(self, xy: Sequence[float], theta: float,
-              arrowwidth: float=.2, arrowlength: float=.2,
+              arrowwidth: float=.15, arrowlength: float=.25,
               color: str='black', lw: float=2, clip: BBox=None, zorder: int=1) -> None:
         ''' Draw an arrowhead '''
         x, y = self.xform(*xy)
@@ -358,11 +358,17 @@ class Figure:
                 theta = math.degrees(math.atan2(delta.y, delta.x))
                 self.arrow(p[0], theta, color=color, lw=1, zorder=zorder,
                            clip=clip, arrowlength=arrowlength, arrowwidth=arrowwidth)
+            elif arrow.startswith('o'):
+                self.circle(p[0], radius=arrowwidth/2, color=color, fill=color, lw=0,
+                           clip=clip, zorder=zorder)
             if '>' in arrow:
                 delta = p[-1] - p[-2]
                 theta = math.degrees(math.atan2(delta.y, delta.x))
                 self.arrow(p[-1], theta, color=color, lw=1, zorder=zorder,
                            clip=clip, arrowlength=arrowlength, arrowwidth=arrowwidth)
+            elif arrow.endswith('o'):
+                self.circle(p[-1], radius=arrowwidth/2, color=color, fill=color, lw=0,
+                           clip=clip, zorder=zorder)
 
     def arc(self, center: Sequence[float], width: float, height: float,
             theta1: float=0, theta2: float=90, angle: float=0,
@@ -406,9 +412,7 @@ class Figure:
             et.set('ry', str(height/2))
             if angle != 0:
                 et.set('transform', f'rotate({angle} {centerx} {centery})')
-            et.set('stroke', color)
-            et.set('stroke-width', str(lw))
-            et.set('fill', 'none')
+            et.set('style', getstyle(color=color, ls=ls, lw=lw))
             self.addclip(et, clip)
             self.svgelements.append((zorder, et))
 
@@ -418,9 +422,7 @@ class Figure:
             d = f'M {startx} {starty}'
             d += f' a {width/2} {height/2} {angle} {flags} {dx} {dy}'
             et.set('d', d)
-            et.set('stroke', color)
-            et.set('stroke-width', str(lw))
-            et.set('fill', 'none')
+            et.set('style', getstyle(color=color, ls=ls, lw=lw))
             self.addclip(et, clip)
             self.svgelements.append((zorder, et))
 
